@@ -1,6 +1,6 @@
 package XML::MyXML;
 # ABSTRACT: A simple-to-use XML module, for parsing and creating XML documents
-$XML::MyXML::VERSION = '1.01';
+$XML::MyXML::VERSION = '1.02';
 use strict;
 use warnings;
 use Carp;
@@ -496,7 +496,7 @@ sub check_xml {
 
 
 package XML::MyXML::Object;
-$XML::MyXML::Object::VERSION = '1.01';
+$XML::MyXML::Object::VERSION = '1.02';
 use Carp;
 use Encode;
 use Scalar::Util qw/ weaken /;
@@ -762,7 +762,7 @@ XML::MyXML - A simple-to-use XML module, for parsing and creating XML documents
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 SYNOPSIS
 
@@ -1122,6 +1122,9 @@ L<https://github.com/akarelas/xml-myxml/issues>.
 I will be notified, and then you'll automatically be notified of progress on
 your bug as I make changes.
 
+You can get notified of new versions of this module for free, by email or RSS,
+at L<https://www.perlmodules.net/viewfeed/distro/XML-MyXML>
+
 =head1 AUTHOR
 
 Alexander Karelas <karjala@karjala.org>
